@@ -100,6 +100,25 @@ class ModelBase(metaclass=abc.ABCMeta):
         predict_y = self.impl.predict(x[self.features].values)
         return metrics.roc_auc_score(y, predict_y, average=average)
 
+    def evs(self, x: pd.DataFrame, y: np.ndarray) -> float:
+        predict_y = self.impl.predict(x[self.features].values)
+        return metrics.mean_absolute_error(y, predict_y)
+
+    def mae(self, x: pd.DataFrame, y: np.ndarray) -> float:
+        predict_y = self.impl.predict(x[self.features].values)
+        return metrics.mean_absolute_error(y, predict_y)
+
+    def mse(self, x: pd.DataFrame, y: np.ndarray) -> float:
+        predict_y = self.impl.predict(x[self.features].values)
+        return metrics.mean_squared_error(y, predict_y)
+
+    def r2_score(self,
+                 x: pd.DataFrame,
+                 y: np.ndarray,
+                 multioutput='uniform_average') -> float:
+        predict_y = self.impl.predict(x[self.features].values)
+        return metrics.r2_score(y, predict_y, multioutput=multioutput)
+
     @property
     def device(self):
         return self.impl
